import { createMemo, untrack } from 'solid-js';

// src/index.ts
function createJSXParser(options) {
  return { id: Symbol(options?.name || "jsx-parser" ) };
}
function createToken(parser, tokenData, render) {
  return (props) => {
    const token = render ? () => untrack(() => render(props)) : () => {
      console.warn(
        `Tokens can only be rendered inside a Parser "${parser.id.description}"`
      );
      return "";
    };
    token[parser.id] = true;
    token.data = tokenData ? tokenData(props) : props;
    return token;
  };
}
function resolveChildren(resolved, children, symbol) {
  if (typeof children === "function" && !children.length) {
    if (symbol in children)
      resolved.push(children);
    else
      resolveChildren(resolved, children(), symbol);
  } else if (Array.isArray(children))
    for (let i = 0; i < children.length; i++)
      resolveChildren(resolved, children[i], symbol);
  else console.warn(`Invalid JSX Element passed to Parser "${symbol.description}":`, children);
  return resolved;
}
function resolveTokens(parser, fn) {
  const children = createMemo(fn);
  return createMemo(() => resolveChildren([], children(), parser.id));
}
function resolveData(parser, fn) {
  const tokens = resolveTokens(parser, fn);
  return () => tokens().map((token) => token.data);
}
function isToken(parser, value) {
  return typeof value === "function" && parser.id in value;
}

export { createJSXParser, createToken, isToken, resolveData, resolveTokens };
