'use strict';

var solidJs = require('solid-js');

// src/index.ts
function createJSXParser(options) {
  return { id: Symbol("") };
}
function createToken(parser, tokenData, render) {
  return (props) => {
    const token = render ? () => solidJs.untrack(() => render(props)) : () => {
      return "";
    };
    token[parser.id] = true;
    token.data = tokenData ? tokenData(props) : props;
    return token;
  };
}
function resolveChildren(resolved, children, symbol) {
  if (typeof children === "function" && !children.length) {
    if (symbol in children)
      resolved.push(children);
    else
      resolveChildren(resolved, children(), symbol);
  } else if (Array.isArray(children))
    for (let i = 0; i < children.length; i++)
      resolveChildren(resolved, children[i], symbol);
  else ;
  return resolved;
}
function resolveTokens(parser, fn) {
  const children = solidJs.createMemo(fn);
  return solidJs.createMemo(() => resolveChildren([], children(), parser.id));
}
function resolveData(parser, fn) {
  const tokens = resolveTokens(parser, fn);
  return () => tokens().map((token) => token.data);
}
function isToken(parser, value) {
  return typeof value === "function" && parser.id in value;
}

exports.createJSXParser = createJSXParser;
exports.createToken = createToken;
exports.isToken = isToken;
exports.resolveData = resolveData;
exports.resolveTokens = resolveTokens;
